==> camel-consul-2.18.2-sources.jar: org/apache/camel/component/consul/enpoint/ConsulAgentProducer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.consul.enpoint;

import com.orbitz.consul.AgentClient;
import org.apache.camel.component.consul.AbstractConsulProducer;
import org.apache.camel.component.consul.ConsulConfiguration;
import org.apache.camel.component.consul.ConsulEndpoint;

public class ConsulAgentProducer extends AbstractConsulProducer<AgentClient> {

    public ConsulAgentProducer(ConsulEndpoint endpoint, ConsulConfiguration configuration) {
        super(endpoint, configuration, c -> c.agentClient());

        bind(ConsulAgentActions.CHECKS, wrap(c -> c.getChecks()));
        bind(ConsulAgentActions.SERVICES, wrap(c -> c.getServices()));
        bind(ConsulAgentActions.MEMBERS, wrap(c -> c.getMembers()));
        bind(ConsulAgentActions.AGENT, wrap(c -> c.getAgent()));
    }
}

==> camel-consul-2.20.2-sources.jar: org/apache/camel/component/consul/enpoint/ConsulAgentProducer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.consul.enpoint;

import com.orbitz.consul.AgentClient;
import com.orbitz.consul.Consul;
import org.apache.camel.component.consul.ConsulConfiguration;
import org.apache.camel.component.consul.ConsulEndpoint;

public final class ConsulAgentProducer extends AbstractConsulProducer<AgentClient> {

    public ConsulAgentProducer(ConsulEndpoint endpoint, ConsulConfiguration configuration) {
        super(endpoint, configuration, Consul::agentClient);

        bind(ConsulAgentActions.CHECKS, wrap(c -> c.getChecks()));
        bind(ConsulAgentActions.SERVICES, wrap(c -> c.getServices()));
        bind(ConsulAgentActions.MEMBERS, wrap(c -> c.getMembers()));
        bind(ConsulAgentActions.AGENT, wrap(c -> c.getAgent()));
    }
}
